{% block sidenav %}
<ul>
  <li class="logo">
    <div class="background">
      <img src="{{ gdoc_logo }}" alt="">
    </div>
  </li>
  <li><div class="divider"></div></li>
  <li class="nav-wrapper">
    <form>
      <div class="input-field">
        <input id="search" type="search" required>
        <label class="label-icon" for="search"><i class="material-icons">search</i></label>
        <i class="material-icons">close</i>
      </div>
    </form>
  </li>
  <li><div class="divider"></div></li>
</ul>
    
<ul id="menu-fields">
  {% for field in sidemenu %}
  <li>
    <a class="waves-effect" href="{%url 'graphqldoc:detail' field %}">{{ field }}</a>
  </li>
  {% endfor %}
</ul>

{% endblock %}
