.badge.new {
    font-weight: bold !important;
}

table.compact-table td {
    padding: 0%;
    display: table-cell;
    text-align: left;
    vertical-align: middle;
}

.container {
    width: 100% !important;
}

.gdoc-sidenav {
    border-right: 1px solid lightgrey;
}

.gdoc-sidenav li a {
    color: gray;
    display: block;
    line-height: 48px;
}
.gdoc-sidenav li a:hover {
    background-color: rgb(247, 247, 247);
}

.gdoc-sidenav ul li.logo {
    text-align: center;
    margin-top: 32px;
    margin-bottom: 32px;
}

.gdoc-sidenav ul li img {
    max-height: 70px;
}
